window.Gleam.initSearch([{"doc":"wisp_flash","title":"wisp_flash","content":"# wisp_flash\n\nMiddleware to add flash messages in Wisp\n\n[![Package Version](https://img.shields.io/hexpm/v/wisp_flash)](https://hex.pm/packages/wisp_flash)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/wisp_flash/)\n\n## Setting the flash message\n\nIn your handler:\n\n```gleam\nwisp.redirect(&quot;/home&quot;)\n|&gt; wisp_flash.set_flash(request, &quot;success&quot;, &quot;Document Saved&quot;)\n```\n\n## Retrieving the flash message\n\nIn your router:\n\n```gleam\nuse kind, message &lt;- wisp_flash.get_flash(request)\n\nlet ctx = Context(..ctx, flash_kind: kind, flash_message: message)\n```\n\nIn your view:\n\n```gleam\nfn alert(ctx: Context) {\n  case ctx.flash_message {\n    Some(flash_message) -&gt; {\n      let kind = ctx.flash_kind |&gt; option.unwrap(&quot;notice&quot;)\n\n      ...\n    }\n    None -&gt; div([], [])\n  }\n}\n```\n","url":"index.html"},{"doc":"wisp_flash","title":"get_flash","content":"pub fn get_flash(\n  request: Request(Connection),\n  next: fn(Option(String), Option(String)) -&gt; Response(Body),\n) -&gt; Response(Body)\n Get the flash message and kind.\n This middleware goes around your request.\n This gets the values from the cookies and then deletes them.\n The middleware callback will return the alert kind and message.\n After putting these values in the context, you can use them to render alerts in your view.\n\n ## Example\n\n \n use kind, message &lt;- wisp_flash.get_flash(request)\n\n let ctx = Context(..ctx, flash_kind: kind, flash_message: message)\n \nSynonyms:\nwisp_flash.get_flash\nwisp_flash get_flash","url":"wisp_flash.html#get_flash"},{"doc":"wisp_flash","title":"set_flash","content":"pub fn set_flash(\n  response response: Response(Body),\n  request request: Request(Connection),\n  kind kind: String,\n  message message: String,\n) -&gt; Response(Body)\n Set a flash message in the session cookie.\n This will store two cookies. One for the message and one for the notification kind.\n\n ## Example\n\n \n wisp.redirect(&quot;/home&quot;)\n |&gt; wisp_flash.set_flash(request, &quot;success&quot;, &quot;Document Saved&quot;)\n \nSynonyms:\nwisp_flash.set_flash\nwisp_flash set_flash","url":"wisp_flash.html#set_flash"},{"doc":"wisp_flash","title":"wisp_flash","content":"","url":"wisp_flash.html"}]);